# Changelog

All notable changes to `gstat_exporter` will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


## [v0.1.0] - 2023-12-13

### Changed
- Create Python package
- Rename default branch from "master" to "main"


### Added

- CHANGELOG.md
- RELEASE.md
